document

package
v1.11.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 20, 2026 License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Overview

Package document provides a document internal utils.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CreateDocument

func CreateDocument(content string, name string) *document.Document

CreateDocument creates a new document with the given content and name.

func CreateDocumentFromPayload added in v1.9.0

func CreateDocumentFromPayload(payload *codeast.DocumentPayload) *document.Document

CreateDocumentFromPayload creates a document from a code AST payload.

func GenerateDocumentID

func GenerateDocumentID(name string, content string) string

GenerateDocumentID generates a unique ID for a document. Uses content hash for identification and random bytes for uniqueness.

Types

This section is empty.

Jump to