Documentation
¶
Overview ¶
Package document provides a document internal utils.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CreateDocument ¶
CreateDocument creates a new document with the given content and name.
func CreateDocumentFromPayload ¶ added in v1.9.0
func CreateDocumentFromPayload(payload *codeast.DocumentPayload) *document.Document
CreateDocumentFromPayload creates a document from a code AST payload.
func GenerateDocumentID ¶
GenerateDocumentID generates a unique ID for a document. Uses content hash for identification and random bytes for uniqueness.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.